from django.utils.translation import gettext_lazy as _
SERVICES = (
    (1,"parking", _("Parking"), "https://yopandyop.s3.us-east-2.amazonaws.com/images/services/parking-area.png"),
    (2, "bar", _("Bar"), "https://yopandyop.s3.us-east-2.amazonaws.com/images/services/cocktail.png"),
    (3, "restaurant", _("Restaurant"), "https://yopandyop.s3.us-east-2.amazonaws.com/images/services/restaurant.png"),
    (4, "club", _("Club"), "https://yopandyop.s3.us-east-2.amazonaws.com/images/services/club.png"),
)